# IP and Verification Package Manager (IVPM)

IVPM is a Python- and Git-centric utility for managing external 
project dependencies.  It was initially designed to manage dependencies
for hardware design projects, but has been used on a variety of other
project styles including purely-software projects.

You can find more detailed documentation on IVPM here: [IVPM docs](https://fvutils.github.io/ivpm)

